##  Freezing Cluster Headers
When you freeze cluster headers, they remain fixed as you scroll through landscape reports with multiple levels. This helps you identify your current position in the cluster hierarchy.
  1. Open a landscape report and choose Settings.
  2. Select the Stick cluster headers on scroll checkbox. ![The Report Settings dialog with the Stick cluster headers on scroll option highlighted.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio65c71be7d1ad48f9aa95e2ab87047f65_LowRes.png)
  3. Choose Apply.
The cluster headers remain fixed as you scroll, so you can always see the active cluster.


Freezing Cluster Headers in a Landscape Report
![Animated image showing cluster headers remaining fixed in an application landscape report.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4f389465c1e74055ad3c210ad2bd1390_LowRes.gif)
